==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/uk_ua/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.add.field_logged_in'] = 'Ви повинні увійти в систему';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = 'Скасувати';
$lang['AdminMain.editcategory.submit_edit'] = 'Оновити категорію';
$lang['AdminMain.editcategory.field_description'] = 'Опис';
$lang['AdminMain.editcategory.field_name'] = 'Ім\'я';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Оновити категорію [%1$s]';
$lang['AdminMain.editcategory.page_title'] = 'Диспетчер завантажень > Оновити категорію';
$lang['AdminMain.addcategory.submit_cancel'] = 'Скасувати';
$lang['AdminMain.addcategory.submit_add'] = 'Створити категорію';
$lang['AdminMain.addcategory.field_description'] = 'Опис';
$lang['AdminMain.addcategory.field_name'] = 'Ім\'я';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Додати категорію до категорії [%1$s]';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Додати категорію до %1$s';
$lang['AdminMain.addcategory.page_title'] = 'Диспетчер завантажень > Додати категорію';
$lang['AdminMain.editurl.submit_cancel'] = 'Скасувати';
$lang['AdminMain.editurl.submit_add'] = 'Редагувати URL-адресу';
$lang['AdminMain.editurl.field_category'] = 'Категорія';
$lang['AdminMain.editurl.field_file'] = 'Файл';
$lang['AdminMain.editurl.field_url'] = 'Назва URL-адреси';
$lang['AdminMain.editurl.boxtitle_add'] = 'Редагування статичної URL-адреси';
$lang['AdminMain.editurl.page_title'] = 'Диспетчер завантажень > Редагувати статичну URL-адресу';
$lang['AdminMain.edit.submit_cancel'] = 'Скасувати';
$lang['AdminMain.edit.submit_edit'] = 'Оновлення Завантажити';
$lang['AdminMain.edit.field_file_name'] = 'Шлях до файлу';
$lang['AdminMain.edit.field_file'] = 'Файл';
$lang['AdminMain.edit.field_path'] = 'Вкажіть шлях до файлу';
$lang['AdminMain.edit.field_upload'] = 'Завантажити файл';
$lang['AdminMain.edit.text_availablepackages'] = 'Доступні пакети';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Доступні групи клієнтів';
$lang['AdminMain.edit.text_packagegroups'] = 'Вибрані пакети';
$lang['AdminMain.edit.text_clientgroups'] = 'Вибрані групи клієнтів';
$lang['AdminMain.edit.field_available_to_packages'] = 'Доступно для пакунків';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Доступно для груп клієнтів';
$lang['AdminMain.edit.field_name'] = 'Ім\'я';
$lang['AdminMain.edit.field_logged_in'] = 'Ви повинні увійти в систему';
$lang['AdminMain.edit.field_public'] = 'Загальнодоступний';
$lang['AdminMain.edit.boxtitle_edit'] = 'Оновлення Завантажити';
$lang['AdminMain.edit.page_title'] = 'Диспетчер завантажень > Додати завантаження';
$lang['AdminMain.addurl.submit_cancel'] = 'Скасувати';
$lang['AdminMain.addurl.submit_add'] = 'Додати URL-адресу';
$lang['AdminMain.addurl.field_category'] = 'Категорія';
$lang['AdminMain.addurl.field_file'] = 'Файл';
$lang['AdminMain.addurl.field_url'] = 'Назва URL-адреси';
$lang['AdminMain.addurl.boxtitle_add'] = 'Додати статичну URL-адресу';
$lang['AdminMain.addurl.page_title'] = 'Диспетчер завантажень > Додати статичну URL-адресу';
$lang['AdminMain.add.submit_cancel'] = 'Скасувати';
$lang['AdminMain.add.submit_add'] = 'Додати завантаження';
$lang['AdminMain.add.field_file_name'] = 'Шлях до файлу';
$lang['AdminMain.add.field_file'] = 'Файл';
$lang['AdminMain.add.field_path'] = 'Вкажіть шлях до файлу';
$lang['AdminMain.add.field_upload'] = 'Завантажити файл';
$lang['AdminMain.add.text_availablepackages'] = 'Доступні пакети';
$lang['AdminMain.add.text_availableclientgroups'] = 'Доступні групи клієнтів';
$lang['AdminMain.add.text_packagegroups'] = 'Вибрані пакети';
$lang['AdminMain.add.text_clientgroups'] = 'Вибрані групи клієнтів';
$lang['AdminMain.add.field_available_to_packages'] = 'Доступно для пакунків';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Доступно для груп клієнтів';
$lang['AdminMain.add.field_name'] = 'Ім\'я';
$lang['AdminMain.add.field_public'] = 'Загальнодоступний';
$lang['AdminMain.add.boxtitle_add'] = 'Додати завантаження до категорії [%1$s]';
$lang['AdminMain.add.boxtitle_root'] = 'Додати завантаження до %1$s';
$lang['AdminMain.add.page_title'] = 'Диспетчер завантажень > Додати завантаження';
$lang['AdminMain.urls.no_urls'] = 'У цьому розділі немає статичних URL-адрес.';
$lang['AdminMain.urls.latest_file'] = 'Останній файл від <strong>%1$s</strong>';
$lang['AdminMain.urls.delete'] = 'Видалити';
$lang['AdminMain.urls.edit'] = 'Редагувати';
$lang['AdminMain.urls.heading_options'] = 'Параметри';
$lang['AdminMain.urls.heading_link'] = 'Посилання';
$lang['AdminMain.urls.heading_file'] = 'Файл';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.tab_urls'] = 'Статичні URL-адреси';
$lang['AdminMain.urls.tab_files'] = 'Файли';
$lang['AdminMain.urls.add_url'] = 'Додати статичну URL-адресу';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Менеджер завантажень';
$lang['AdminMain.urls.page_title'] = 'Диспетчер завантажень > Керування';
$lang['AdminMain.files.no_downloads'] = 'У цьому розділі немає завантажень.';
$lang['AdminMain.files.delete'] = 'Видалити';
$lang['AdminMain.files.edit'] = 'Редагувати';
$lang['AdminMain.files.go_back'] = 'Підніміться на рівень вище.';
$lang['AdminMain.files.add_category'] = 'Додати категорію тут';
$lang['AdminMain.files.add_download'] = 'Додати завантаження тут';
$lang['AdminMain.files.tab_urls'] = 'Статичні URL-адреси';
$lang['AdminMain.files.tab_files'] = 'Файли';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Менеджер завантажень';
$lang['AdminMain.files.page_title'] = 'Диспетчер завантажень > Керування';
$lang['AdminMain.modal.delete_url'] = 'Ви впевнені, що хочете видалити цю статичну URL-адресу?';
$lang['AdminMain.modal.delete_category'] = 'Ви впевнені, що хочете видалити цю категорію? Всі підкатегорії та файли в цій категорії будуть переміщені до батьківської категорії.';
$lang['AdminMain.modal.delete_file'] = 'Ви впевнені, що хочете видалити цей файл?';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = 'Головний каталог';
$lang['AdminMain.!tooltip.category_type'] = 'URL-адреса вказуватиме на останній файл, завантажений до цієї категорії.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Введіть абсолютний шлях до файлу у файловій системі.';
$lang['AdminMain.!success.url_updated'] = 'Статичну URL-адресу успішно оновлено.';
$lang['AdminMain.!success.url_added'] = 'Статичну URL-адресу успішно додано.';
$lang['AdminMain.!success.url_deleted'] = 'Статичну URL-адресу успішно видалено.';
$lang['AdminMain.!success.file_deleted'] = 'Файл успішно видалено.';
$lang['AdminMain.!success.file_updated'] = 'Файл успішно оновлено.';
$lang['AdminMain.!success.file_added'] = 'Файл успішно додано.';
$lang['AdminMain.!success.category_deleted'] = 'Категорію успішно видалено.';
$lang['AdminMain.!success.category_updated'] = 'Категорію успішно оновлено.';
$lang['AdminMain.!success.category_added'] = 'Категорія успішно створена.';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/uk_ua/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.add.field_logged_in'] = 'Ви повинні увійти в систему';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = 'Скасувати';
$lang['AdminMain.editcategory.submit_edit'] = 'Оновити категорію';
$lang['AdminMain.editcategory.field_description'] = 'Опис';
$lang['AdminMain.editcategory.field_name'] = 'Ім\'я';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Оновити категорію [%1$s]';
$lang['AdminMain.editcategory.page_title'] = 'Диспетчер завантажень > Оновити категорію';
$lang['AdminMain.addcategory.submit_cancel'] = 'Скасувати';
$lang['AdminMain.addcategory.submit_add'] = 'Створити категорію';
$lang['AdminMain.addcategory.field_description'] = 'Опис';
$lang['AdminMain.addcategory.field_name'] = 'Ім\'я';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Додати категорію до категорії [%1$s]';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Додати категорію до %1$s';
$lang['AdminMain.addcategory.page_title'] = 'Диспетчер завантажень > Додати категорію';
$lang['AdminMain.editurl.submit_cancel'] = 'Скасувати';
$lang['AdminMain.editurl.submit_add'] = 'Редагувати URL-адресу';
$lang['AdminMain.editurl.field_category'] = 'Категорія';
$lang['AdminMain.editurl.field_file'] = 'Файл';
$lang['AdminMain.editurl.field_url'] = 'Назва URL-адреси';
$lang['AdminMain.editurl.boxtitle_add'] = 'Редагування статичної URL-адреси';
$lang['AdminMain.editurl.page_title'] = 'Диспетчер завантажень > Редагувати статичну URL-адресу';
$lang['AdminMain.edit.submit_cancel'] = 'Скасувати';
$lang['AdminMain.edit.submit_edit'] = 'Оновлення Завантажити';
$lang['AdminMain.edit.field_file_name'] = 'Шлях до файлу';
$lang['AdminMain.edit.field_file'] = 'Файл';
$lang['AdminMain.edit.field_path'] = 'Вкажіть шлях до файлу';
$lang['AdminMain.edit.field_upload'] = 'Завантажити файл';
$lang['AdminMain.edit.text_availablepackages'] = 'Доступні пакети';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Доступні групи клієнтів';
$lang['AdminMain.edit.text_packagegroups'] = 'Вибрані пакети';
$lang['AdminMain.edit.text_clientgroups'] = 'Вибрані групи клієнтів';
$lang['AdminMain.edit.field_available_to_packages'] = 'Доступно для пакунків';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Доступно для груп клієнтів';
$lang['AdminMain.edit.field_name'] = 'Ім\'я';
$lang['AdminMain.edit.field_logged_in'] = 'Ви повинні увійти в систему';
$lang['AdminMain.edit.field_public'] = 'Загальнодоступний';
$lang['AdminMain.edit.boxtitle_edit'] = 'Оновлення Завантажити';
$lang['AdminMain.edit.page_title'] = 'Диспетчер завантажень > Додати завантаження';
$lang['AdminMain.addurl.submit_cancel'] = 'Скасувати';
$lang['AdminMain.addurl.submit_add'] = 'Додати URL-адресу';
$lang['AdminMain.addurl.field_category'] = 'Категорія';
$lang['AdminMain.addurl.field_file'] = 'Файл';
$lang['AdminMain.addurl.field_url'] = 'Назва URL-адреси';
$lang['AdminMain.addurl.boxtitle_add'] = 'Додати статичну URL-адресу';
$lang['AdminMain.addurl.page_title'] = 'Диспетчер завантажень > Додати статичну URL-адресу';
$lang['AdminMain.add.submit_cancel'] = 'Скасувати';
$lang['AdminMain.add.submit_add'] = 'Додати завантаження';
$lang['AdminMain.add.field_file_name'] = 'Шлях до файлу';
$lang['AdminMain.add.field_file'] = 'Файл';
$lang['AdminMain.add.field_path'] = 'Вкажіть шлях до файлу';
$lang['AdminMain.add.field_upload'] = 'Завантажити файл';
$lang['AdminMain.add.text_availablepackages'] = 'Доступні пакети';
$lang['AdminMain.add.text_availableclientgroups'] = 'Доступні групи клієнтів';
$lang['AdminMain.add.text_packagegroups'] = 'Вибрані пакети';
$lang['AdminMain.add.text_clientgroups'] = 'Вибрані групи клієнтів';
$lang['AdminMain.add.field_available_to_packages'] = 'Доступно для пакунків';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Доступно для груп клієнтів';
$lang['AdminMain.add.field_name'] = 'Ім\'я';
$lang['AdminMain.add.field_public'] = 'Загальнодоступний';
$lang['AdminMain.add.boxtitle_add'] = 'Додати завантаження до категорії [%1$s]';
$lang['AdminMain.add.boxtitle_root'] = 'Додати завантаження до %1$s';
$lang['AdminMain.add.page_title'] = 'Диспетчер завантажень > Додати завантаження';
$lang['AdminMain.urls.no_urls'] = 'У цьому розділі немає статичних URL-адрес.';
$lang['AdminMain.urls.latest_file'] = 'Останній файл від <strong>%1$s</strong>';
$lang['AdminMain.urls.delete'] = 'Видалити';
$lang['AdminMain.urls.edit'] = 'Редагувати';
$lang['AdminMain.urls.heading_options'] = 'Параметри';
$lang['AdminMain.urls.heading_link'] = 'Посилання';
$lang['AdminMain.urls.heading_file'] = 'Файл';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.tab_urls'] = 'Статичні URL-адреси';
$lang['AdminMain.urls.tab_files'] = 'Файли';
$lang['AdminMain.urls.add_url'] = 'Додати статичну URL-адресу';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Менеджер завантажень';
$lang['AdminMain.urls.page_title'] = 'Диспетчер завантажень > Керування';
$lang['AdminMain.files.no_downloads'] = 'У цьому розділі немає завантажень.';
$lang['AdminMain.files.delete'] = 'Видалити';
$lang['AdminMain.files.edit'] = 'Редагувати';
$lang['AdminMain.files.go_back'] = 'Підніміться на рівень вище.';
$lang['AdminMain.files.add_category'] = 'Додати категорію тут';
$lang['AdminMain.files.add_download'] = 'Додати завантаження тут';
$lang['AdminMain.files.tab_urls'] = 'Статичні URL-адреси';
$lang['AdminMain.files.tab_files'] = 'Файли';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Менеджер завантажень';
$lang['AdminMain.files.page_title'] = 'Диспетчер завантажень > Керування';
$lang['AdminMain.modal.delete_url'] = 'Ви впевнені, що хочете видалити цю статичну URL-адресу?';
$lang['AdminMain.modal.delete_category'] = 'Ви впевнені, що хочете видалити цю категорію? Всі підкатегорії та файли в цій категорії будуть переміщені до батьківської категорії.';
$lang['AdminMain.modal.delete_file'] = 'Ви впевнені, що хочете видалити цей файл?';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = 'Головний каталог';
$lang['AdminMain.!tooltip.category_type'] = 'URL-адреса вказуватиме на останній файл, завантажений до цієї категорії.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Введіть абсолютний шлях до файлу у файловій системі.';
$lang['AdminMain.!success.url_updated'] = 'Статичну URL-адресу успішно оновлено.';
$lang['AdminMain.!success.url_added'] = 'Статичну URL-адресу успішно додано.';
$lang['AdminMain.!success.url_deleted'] = 'Статичну URL-адресу успішно видалено.';
$lang['AdminMain.!success.file_deleted'] = 'Файл успішно видалено.';
$lang['AdminMain.!success.file_updated'] = 'Файл успішно оновлено.';
$lang['AdminMain.!success.file_added'] = 'Файл успішно додано.';
$lang['AdminMain.!success.category_deleted'] = 'Категорію успішно видалено.';
$lang['AdminMain.!success.category_updated'] = 'Категорію успішно оновлено.';
$lang['AdminMain.!success.category_added'] = 'Категорія успішно створена.';
$lang['AdminMain.edit.text_full_path'] = 'ПРИМІТКА: Файли мають бути розміщені десь у вашому каталозі завантажень: <strong>%1$s</strong>.';
$lang['AdminMain.add.text_full_path'] = 'ПРИМІТКА: Файли мають бути розміщені десь у вашому каталозі завантажень: <strong>%1$s</strong>.';
